### Changes

<!-- Describe briefly what changed. -->

### Follow-up work

<!-- Describe necessary future changes that will be in a separate PR. -->

### Steps to reproduce

<!-- Describe how a reviewer can see the changes in action. -->

### Affected use-cases

<!-- Describe use-cases that may be affected by side effects of the changes. -->

### Review Checklist

<!-- Describe things a reviewer should do before approving the PR. -->

- [ ] The changes are understood.
- [ ] The changes are well documented.
- [ ] The changes have been tested.

